@@ -979,6 +979,33 @@ int check_hostname_matches_domain(const char *hostname, const char *domain)
 }
 
 
+/*
+ * domain_is_non_ascii()
+ *
+ * see tools.h
+ */
+
+int domain_is_non_ascii(const char *address)
+{
+    int in_domain_part = 0;
+    int non_ascii = 0;
+    for (int i = 0; address[i]; i++)
+    {
+        if (!in_domain_part && address[i] == '@')
+        {
+            in_domain_part = 1;
+            continue;
+        }
+        if (in_domain_part && (address[i] < 32 || address[i] >= 127))
+        {
+            non_ascii = 1;
+            break;
+        }
+    }
+    return non_ascii;
+}
+
+
 /*
  * encode_for_header()
  *
@@ -1012,7 +1039,13 @@ char *encode_for_header(const char *s)
         size_t b64_s_len = BASE64_LENGTH(s_len);
         char* encoding =
 #ifdef HAVE_LANGINFO_H
+            /* With disabled NLS, nl_langinfo() always seems to return
+             * ANSI_X3.4-1968 (i.e. ASCII). We want to assume UTF-8 instead. */
+# ifdef ENABLE_NLS
                 nl_langinfo(CODESET);
+# else
+                "UTF-8";
+# endif
 #else
 # ifdef W32_NATIVE
                 w32_langinfo_codeset();
